<no title> — r2lab v0.6.2

# The r2lab python library

This python module contains, in no particular order, a set of utilities that come in handy when working with the R2lab testbed - see <https://r2lab.inria.fr>.

This library was built on an opportunistic basis; essentially, it contains features that we found users copying and pasting from one experience to another.

As such it addresses very different topics, but nothing in here should be crucial or really hard to implement separately, it’s mostly meant as a set of convenient tools to help experimenter provide similar functionalities.